( cd sbin ; rm -rf ramsize )
( cd sbin ; ln -sf rdev ramsize )
( cd sbin ; rm -rf swapdev )
( cd sbin ; ln -sf rdev swapdev )
( cd sbin ; rm -rf swapoff )
( cd sbin ; ln -sf swapon swapoff )
( cd sbin ; rm -rf vidmode )
( cd sbin ; ln -sf rdev vidmode )
( cd sbin ; rm -rf mount )
( cd sbin ; ln -sf /bin/mount mount )
( cd sbin ; rm -rf umount )
( cd sbin ; ln -sf /bin/umount umount )
( cd sbin ; rm -rf rootflags )
( cd sbin ; ln -sf rdev rootflags )
( cd sbin ; rm -rf update )
( cd sbin ; ln -sf bdflush update )
( cd usr/bin ; rm -rf more )
( cd usr/bin ; ln -sf /bin/more more )
( cd usr/bin ; rm -rf banner )
( cd usr/bin ; ln -sf /cdrom/usr/bin/banner banner )
( cd usr/bin ; rm -rf cal )
( cd usr/bin ; ln -sf /cdrom/usr/bin/cal cal )
( cd usr/bin ; rm -rf chsh )
( cd usr/bin ; ln -sf /cdrom/usr/bin/chsh chsh )
( cd usr/bin ; rm -rf clear )
( cd usr/bin ; ln -sf /cdrom/usr/bin/clear clear )
( cd usr/bin ; rm -rf col )
( cd usr/bin ; ln -sf /cdrom/usr/bin/col col )
( cd usr/bin ; rm -rf colcrt )
( cd usr/bin ; ln -sf /cdrom/usr/bin/colcrt colcrt )
( cd usr/bin ; rm -rf colrm )
( cd usr/bin ; ln -sf /cdrom/usr/bin/colrm colrm )
( cd usr/bin ; rm -rf column )
( cd usr/bin ; ln -sf /cdrom/usr/bin/column column )
( cd usr/bin ; rm -rf fdformat )
( cd usr/bin ; ln -sf /cdrom/usr/bin/fdformat fdformat )
( cd usr/bin ; rm -rf hexdump )
( cd usr/bin ; ln -sf /cdrom/usr/bin/hexdump hexdump )
( cd usr/bin ; rm -rf ipcrm )
( cd usr/bin ; ln -sf /cdrom/usr/bin/ipcrm ipcrm )
( cd usr/bin ; rm -rf ipcs )
( cd usr/bin ; ln -sf /cdrom/usr/bin/ipcs ipcs )
( cd usr/bin ; rm -rf last )
( cd usr/bin ; ln -sf /cdrom/usr/bin/last last )
( cd usr/bin ; rm -rf logger )
( cd usr/bin ; ln -sf /cdrom/usr/bin/logger logger )
( cd usr/bin ; rm -rf look )
( cd usr/bin ; ln -sf /cdrom/usr/bin/look look )
( cd usr/bin ; rm -rf mesg )
( cd usr/bin ; ln -sf /cdrom/usr/bin/mesg mesg )
( cd usr/bin ; rm -rf newgrp )
( cd usr/bin ; ln -sf /cdrom/usr/bin/newgrp newgrp )
( cd usr/bin ; rm -rf passwd )
( cd usr/bin ; ln -sf /cdrom/usr/bin/passwd passwd )
( cd usr/bin ; rm -rf renice )
( cd usr/bin ; ln -sf /cdrom/usr/bin/renice renice )
( cd usr/bin ; rm -rf reset )
( cd usr/bin ; ln -sf /cdrom/usr/bin/reset reset )
( cd usr/bin ; rm -rf rev )
( cd usr/bin ; ln -sf /cdrom/usr/bin/rev rev )
( cd usr/bin ; rm -rf script )
( cd usr/bin ; ln -sf /cdrom/usr/bin/script script )
( cd usr/bin ; rm -rf setfdprm )
( cd usr/bin ; ln -sf /cdrom/usr/bin/setfdprm setfdprm )
( cd usr/bin ; rm -rf setsid )
( cd usr/bin ; ln -sf /cdrom/usr/bin/setsid setsid )
( cd usr/bin ; rm -rf strings )
( cd usr/bin ; ln -sf /cdrom/usr/bin/strings strings )
( cd usr/bin ; rm -rf tsort )
( cd usr/bin ; ln -sf /cdrom/usr/bin/tsort tsort )
( cd usr/bin ; rm -rf ul )
( cd usr/bin ; ln -sf /cdrom/usr/bin/ul ul )
( cd usr/bin ; rm -rf wall )
( cd usr/bin ; ln -sf /cdrom/usr/bin/wall wall )
( cd usr/bin ; rm -rf whereis )
( cd usr/bin ; ln -sf /cdrom/usr/bin/whereis whereis )
( cd usr/bin ; rm -rf write )
( cd usr/bin ; ln -sf /cdrom/usr/bin/write write )
( cd usr/bin ; rm -rf zdump )
( cd usr/bin ; ln -sf /cdrom/usr/bin/zdump zdump )
( cd usr/bin ; rm -rf zic )
( cd usr/bin ; ln -sf /cdrom/usr/bin/zic zic )
( cd usr/bin ; rm -rf namei )
( cd usr/bin ; ln -sf /cdrom/usr/bin/namei namei )
( cd usr/bin ; rm -rf tunelp )
( cd usr/bin ; ln -sf /cdrom/usr/bin/tunelp tunelp )
( cd usr/bin ; rm -rf lpcntl )
( cd usr/bin ; ln -sf /cdrom/usr/bin/lpcntl lpcntl )
( cd usr/bin ; rm -rf hostid )
( cd usr/bin ; ln -sf /cdrom/usr/bin/hostid hostid )
( cd usr/bin ; rm -rf ddate )
( cd usr/bin ; ln -sf /cdrom/usr/bin/ddate ddate )
( cd usr/bin ; rm -rf dsplit )
( cd usr/bin ; ln -sf /cdrom/usr/bin/dsplit dsplit )
( cd usr ; rm -rf info )
( cd usr ; ln -sf /cdrom/usr/info info )
( cd usr/lib ; rm -rf more.help )
( cd usr/lib ; ln -sf /cdrom/usr/lib/more.help more.help )
( cd usr ; rm -rf man )
( cd usr ; ln -sf /cdrom/usr/man man )
( cd usr/sbin ; rm -rf chroot )
( cd usr/sbin ; ln -sf /cdrom/usr/sbin/chroot chroot )
( cd usr/sbin ; rm -rf ctrlaltdel )
( cd usr/sbin ; ln -sf /cdrom/usr/sbin/ctrlaltdel ctrlaltdel )
( cd usr/sbin ; rm -rf frag )
( cd usr/sbin ; ln -sf /cdrom/usr/sbin/frag frag )
( cd usr/sbin ; rm -rf cfdisk )
( cd usr/sbin ; ln -sf /cdrom/usr/sbin/cfdisk cfdisk )
( cd usr/doc ; rm -rf util-linux-1.10 )
( cd usr/doc ; ln -sf /cdrom/usr/doc/util-linux-1.10 util-linux-1.10 )
